@@ -10,14 +10,12 @@
 
 module Crypto.Cipher.Blowfish (Blowfish, Key, initKey, encrypt, decrypt) where
 
-import Crypto.Classes
 import Data.Vector (Vector, (!), (//))
 import qualified Data.Vector as V
 import Data.Bits
 import Data.Char
 import Data.Word
 import qualified Data.ByteString as B
-import Data.Tagged
 import Data.Serialize
 
 type Pbox = Vector Word32
@@ -32,7 +30,7 @@ data Key = Key { unKey :: Vector Word32 }
 
 encrypt, decrypt :: Key -> B.ByteString -> B.ByteString
 encrypt = cipher . selectEncrypt . bfState . initBoxes
-decrypt = cipher . selectEncrypt . bfState . initBoxes
+decrypt = cipher . selectDecrypt . bfState . initBoxes
 
 instance Serialize Blowfish where
     put = put . bfKey
@@ -46,13 +44,6 @@ instance Serialize Key where
             Right k -> return k
             Left _ -> fail "Invalid raw key material."
 
-instance BlockCipher Blowfish where
-	blockSize    = Tagged 64
-	encryptBlock = cipher . selectEncrypt . bfState
-	decryptBlock = cipher . selectDecrypt . bfState
-	buildKey     = either (const Nothing) (Just . initBoxes) . initKey
-	keyLength    = Tagged 448 -- Actually 1 through 448 inclusive.
-
 selectEncrypt, selectDecrypt :: BlowfishState -> (Pbox, BlowfishState)
 selectEncrypt x@(BF p _ _ _ _) = (p, x)
 selectDecrypt x@(BF p _ _ _ _) = (V.reverse p, x)
